==> j2sdk-1_4_2_03-i586-1.tgz: com/sun/java/swing/plaf/gtk/resources/gtk_zh_CN.java <==
package com.sun.java.swing.plaf.gtk.resources;

import java.util.ListResourceBundle;

public final class gtk_zh_CN extends ListResourceBundle {
    private static final Object[][] contents = {
        { "FileChooser.acceptAllFileFilterText", "*" },
        { "FileChooser.cancelButtonText", "\u53D6\u6D88" },
        { "FileChooser.cancelButtonToolTipText", "\u7EC8\u6B62\u6587\u4EF6\u9009\u62E9\u5668\u5BF9\u8BDD\u6846\u3002" },
        { "FileChooser.deleteFileButtonText", "\u5220\u9664\u6587\u4EF6" },
        { "FileChooser.filesLabelText", "\u6587\u4EF6" },
        { "FileChooser.foldersLabelText", "\u6587\u4EF6\u5939" },
        { "FileChooser.newFolderButtonText", "\u65B0\u5EFA\u6587\u4EF6\u5939" },
        { "FileChooser.openButtonText", "\u786E\u5B9A" },
        { "FileChooser.openButtonToolTipText", "\u6253\u5F00\u9009\u5B9A\u7684\u6587\u4EF6\u3002" },
        { "FileChooser.openDialogTitleText", "\u6253\u5F00" },
        { "FileChooser.pathLabelText", "\u9009\u62E9\uFF1A" },
        { "FileChooser.renameFileButtonText", "\u91CD\u547D\u540D\u6587\u4EF6" },
        { "FileChooser.saveButtonText", "\u4FDD\u5B58" },
        { "FileChooser.saveButtonToolTipText", "\u4FDD\u5B58\u9009\u5B9A\u7684\u6587\u4EF6\u3002" },
        { "FileChooser.saveDialogTitleText", "\u4FDD\u5B58" },
        { "GTKColorChooserPanel.blueMnemonic", "66" },
        { "GTKColorChooserPanel.blueText", "\u84DD(B)\uFF1A" },
        { "GTKColorChooserPanel.colorNameMnemonic", "78" },
        { "GTKColorChooserPanel.colorNameText", "\u989C\u8272\u540D\u79F0(N)\uFF1A" },
        { "GTKColorChooserPanel.greenMnemonic", "71" },
        { "GTKColorChooserPanel.greenText", "\u7EFF(G)\uFF1A" },
        { "GTKColorChooserPanel.hueMnemonic", "72" },
        { "GTKColorChooserPanel.hueText", "\u8272\u8C03(H)\uFF1A" },
        { "GTKColorChooserPanel.mnemonic", "71" },
        { "GTKColorChooserPanel.nameText", "GTK Color Chooser" },
        { "GTKColorChooserPanel.redMnemonic", "82" },
        { "GTKColorChooserPanel.redText", "\u7EA2(R)\uFF1A" },
        { "GTKColorChooserPanel.saturationMnemonic", "83" },
        { "GTKColorChooserPanel.saturationText", "\u9971\u548C\u5EA6(S)\uFF1A" },
        { "GTKColorChooserPanel.valueMnemonic", "86" },
        { "GTKColorChooserPanel.valueText", "\u503C(V)\uFF1A" },

    };

    protected final Object[][] getContents() {
         return contents;
    }
}

==> j2sdk-1_5_0_01-i586-1.tgz: com/sun/java/swing/plaf/gtk/resources/gtk_zh_CN.java <==
package com.sun.java.swing.plaf.gtk.resources;

import java.util.ListResourceBundle;

public final class gtk_zh_CN extends ListResourceBundle {
    private static final Object[][] contents = {
        { "FileChooser.acceptAllFileFilterText", "\u6240\u6709\u6587\u4EF6" },
        { "FileChooser.cancelButtonText", "\u53D6\u6D88" },
        { "FileChooser.cancelButtonToolTipText", "\u7EC8\u6B62\u6587\u4EF6\u9009\u62E9\u5668\u5BF9\u8BDD\u6846\u3002" },
        { "FileChooser.deleteFileButtonText", "\u5220\u9664\u6587\u4EF6" },
        { "FileChooser.filesLabelText", "\u6587\u4EF6" },
        { "FileChooser.filterLabelText", "\u8FC7\u6EE4\u5668\uFF1A" },
        { "FileChooser.foldersLabelText", "\u6587\u4EF6\u5939" },
        { "FileChooser.newFolderButtonText", "\u65B0\u5EFA\u6587\u4EF6\u5939" },
        { "FileChooser.newFolderDialogText", "\u6587\u4EF6\u5939\u540D\uFF1A" },
        { "FileChooser.openButtonText", "\u786E\u5B9A" },
        { "FileChooser.openButtonToolTipText", "\u6253\u5F00\u9009\u5B9A\u7684\u6587\u4EF6\u3002" },
        { "FileChooser.openDialogTitleText", "\u6253\u5F00" },
        { "FileChooser.pathLabelText", "\u9009\u62E9\uFF1A" },
        { "FileChooser.renameFileButtonText", "\u91CD\u547D\u540D\u6587\u4EF6" },
        { "FileChooser.renameFileDialogText", "\u5C06\u6587\u4EF6\u201C{0}\u201D\u91CD\u547D\u540D\u4E3A" },
        { "FileChooser.renameFileErrorText", "\u5C06\u6587\u4EF6\u201C{0}\u201D\u91CD\u547D\u540D\u4E3A\u201C{1}\u201D\u65F6\u51FA\u9519" },
        { "FileChooser.renameFileErrorTitle", "\u9519\u8BEF" },
        { "FileChooser.saveButtonText", "\u4FDD\u5B58" },
        { "FileChooser.saveButtonToolTipText", "\u4FDD\u5B58\u9009\u5B9A\u7684\u6587\u4EF6\u3002" },
        { "FileChooser.saveDialogTitleText", "\u4FDD\u5B58" },
        { "GTKColorChooserPanel.blueMnemonic", "66" },
        { "GTKColorChooserPanel.blueText", "\u84DD(B)\uFF1A" },
        { "GTKColorChooserPanel.colorNameMnemonic", "78" },
        { "GTKColorChooserPanel.colorNameText", "\u989C\u8272\u540D\u79F0(N)\uFF1A" },
        { "GTKColorChooserPanel.greenMnemonic", "71" },
        { "GTKColorChooserPanel.greenText", "\u7EFF(G)\uFF1A" },
        { "GTKColorChooserPanel.hueMnemonic", "72" },
        { "GTKColorChooserPanel.hueText", "\u8272\u8C03(H)\uFF1A" },
        { "GTKColorChooserPanel.mnemonic", "71" },
        { "GTKColorChooserPanel.nameText", "GTK Color Chooser" },
        { "GTKColorChooserPanel.redMnemonic", "69" },
        { "GTKColorChooserPanel.redText", "\u7EA2(E)\uFF1A" },
        { "GTKColorChooserPanel.saturationMnemonic", "83" },
        { "GTKColorChooserPanel.saturationText", "\u9971\u548C\u5EA6(S)\uFF1A" },
        { "GTKColorChooserPanel.valueMnemonic", "86" },
        { "GTKColorChooserPanel.valueText", "\u503C(V)\uFF1A" },

    };

    protected final Object[][] getContents() {
         return contents;
    }
}
